@@ -6,7 +6,7 @@ package NexTrieve::HTML;
 
 use strict;
 @NexTrieve::HTML::ISA = qw(NexTrieve);
-$NexTrieve::HTML::VERSION = '0.32';
+$NexTrieve::HTML::VERSION = '0.33';
 
 # Use other NexTrieve modules that we need always
 
@@ -293,12 +293,12 @@ NexTrieve::HTML - convert HTML to NexTrieve Document objects
  use NexTrieve;
  $ntv = NexTrieve->new( | {method => value} );
 
- $html = $ntv->HTML( | {method => value} );
+ $converter = $ntv->HTML( | {method => value} );
 
  $index = $ntv->Index( $resource )->htmlsimple;
  $docseq = $index->Docseq;
  foreach my $file (<*.html>) {
-   $docseq->add( $html->Document( $file ) );
+   $docseq->add( $converter->Document( $file ) );
  }
  $docseq->done;
 
@@ -333,7 +333,7 @@ the parameters later by calling the methods on the object.
 
 =item setting parameters
 
-After the object is created, you will have to decide if a preprocesor should
+After the object is created, you will have to decide if a preprocessor should
 process the HTML before anything else (see L<preprocessor>), which fields of
 the content hash should appear as what attributes (see L<field2attribute>)
 and/or texttypes (see L<field2texttype>).
@@ -450,11 +450,11 @@ These methods create objects from the NexTrieve::HTML object.
 
 =head2 Docseq
 
- $docseq = $html->Docseq( @file );
+ $docseq = $converter->Docseq( @file );
  $docseq->write_file( filename );
 
  $index = $ntv->Index( $resource );
- $html->Docseq( $index->Docseq,@file );
+ $converter->Docseq( $index->Docseq,@file );
 
 The Docseq method allows you to create a NexTrieve document sequence object
 (or NexTrieve::Docseq object) out of one or more HTML-files.  This can either
@@ -476,7 +476,7 @@ For more information, see the NexTrieve::Docseq module.
 
 =head2 Document
 
- $document = $html->Document( file | html | [list] , | '' | 'file' | 'url' | sub {} );
+ $document = $converter->Document( file | html | [list] , | '' | 'file' | 'url' | sub {} );
 
 The Document method performs the actual conversion from HTML to XML and
 returns a NexTrieve::Document object that may become part of a NexTrieve
@@ -536,7 +536,7 @@ should be processed.  In list context, it is expected to return:
 
 =head2 Resource
 
- $resource = $html->Resource( | {method => value} );
+ $resource = $converter->Resource( | {method => value} );
 
 The "Resource" method allows you to create a NexTrieve::Resource object from
 the internal structure of the NexTrieve::HTML.pm object.  More specifically,
@@ -554,7 +554,7 @@ These methods change aspects of the NexTrieve::HTML object.
 
 =head2 asp
 
- $html->asp;
+ $converter->asp;
 
 The "asp" method makes sure that <%...%> processor tags are removed from the
 HTML before being processed.  It basically defined a L<preprocessor> routine
@@ -565,7 +565,7 @@ one-liners.
 
 =head2 attribute_processor
 
- $html->attribute_processor( 'attribute', key | sub {} );
+ $converter->attribute_processor( 'attribute', key | sub {} );
 
 The "attribute_processor" allows you to specify a subroutine that will process
 the contents of a specific attribute before it becomes serialized in XML.
@@ -579,8 +579,8 @@ L<PROCESSOR ROUTINES> for more information.
 
 =head2 binarycheck
 
- $html->binarycheck( true | false );
- $binarycheck = $html->binarycheck;
+ $converter->binarycheck( true | false );
+ $binarycheck = $converter->binarycheck;
 
 The "binarycheck" method sets a flag in the object to indicate whether a
 check for binary content should be performed.  If the flag is set and binary
@@ -593,23 +593,23 @@ listed are really HTML, it is probably a good idea to set this flag.
 
 =head2 DefaultInputEncoding
 
- $encoding = $html->DefaultInputEncoding;
- $html->DefaultInputEncoding( encoding );
+ $encoding = $converter->DefaultInputEncoding;
+ $converter->DefaultInputEncoding( encoding );
 
 See the NexTrieve.pm module for more information about the
 "DefaultInputEncoding" method.
 
 =head2 displaycontainers
 
- $html->displaycontainers( qw(a b em font i strike strong tt u) );
- @displaycontainer= $html->displaycontainers;
+ $converter->displaycontainers( qw(a b em font i strike strong tt u) );
+ @displaycontainer= $converter->displaycontainers;
 
 The "displaycontainers" method specifies which HTML-tags should be considered
 HTML-tags that have to do with the display of HTML, rather than with the
 structure of HTML.  During the conversion from HTML to XML, all HTML-tags
 that are considered to be display containers, are completelyb removed from
-the HTML.  This causes the HTML "<B>T</B>ext" to be converted to the single
-word "Text" rather than to two words "T ext".
+the HTML.  This causes the HTML "<B>1</B>234" to be converted to the single
+word "1234" rather than to two words "1 234".
 
 Please note that all HTML-tags that are not known to be display containers,
 or removable containers (see L<removecontainers>) are completely removed from
@@ -619,7 +619,7 @@ The default display containers are: a b em font i strike strong tt u .
 
 =head2 extra_attribute
 
- $html->extra_attribute( [\$var | sub {}, attribute spec] | 'reset' );
+ $converter->extra_attribute( [\$var | sub {}, attribute spec] | 'reset' );
 
 The "extra_attribute" method specifies one or more attributes that should be
 added to the serialized XML, created from sources outside of the original HTML.
@@ -650,7 +650,7 @@ of the object.
 
 =head2 extra_texttype
 
- $html->extra_texttype( [\$var | sub {}, texttype spec] | 'reset' );
+ $converter->extra_texttype( [\$var | sub {}, texttype spec] | 'reset' );
 
 The "extra_texttype" method specifies one or more texttypes that should be
 added to the serialized XML, created from sources outside of the original HTML.
@@ -681,7 +681,7 @@ of the object.
 
 =head2 field2attribute
 
- $html->field2attribute( 'title','date',['id',attribute spec] );
+ $converter->field2attribute( 'title','date',['id',attribute spec] );
 
 The "field2attribute" specifies how a key in the content hash should be mapped
 to an attribute in the serialized XML.
@@ -704,7 +704,7 @@ cause a complete resource-specification if the L<Resource> method is called.
 
 =head2 field2texttype
 
- $html->field2texttype( 'title',[qw(description whatitis 200)],'keywords' );
+ $converter->field2texttype( 'title',[qw(description whatitis 200)],'keywords' );
 
 The "field2texttype" specifies how a key in the content hash should be mapped
 to a texttype in the serialized XML.
@@ -728,7 +728,7 @@ method is called.
 
 =head2 htmlsimple
 
- $html->htmlsimple;
+ $converter->htmlsimple;
 
 The "htmlsimple" method is a convenience method for quickly setting up
 L<field2attribute> and L<field2texttype> mappings.  It is intended to handle
@@ -743,7 +743,7 @@ one-liners.
 
 =head2 mhonarc
 
- $html->mhonarc;
+ $converter->mhonarc;
 
 The "mhonarc"  method is a convenience method for quickly setting up
 L<field2attribute>, L<field2texttype>, L<attribute_processor> and
@@ -764,7 +764,7 @@ one-liners.
 
 =head2 php
 
- $html->php;
+ $converter->php;
 
 The "php" method makes sure that <?...?> and <%...%> processor tags are removed
 from the HTML before being processed.  It basically defined a L<preprocessor>
@@ -777,8 +777,8 @@ one-liners.
 
 =head2 preprocessor
 
- $html->preprocessor( \&preprocess );
- $preprocessor = $html->preprocessor;
+ $converter->preprocessor( \&preprocess );
+ $preprocessor = $converter->preprocessor;
 
 The "preprocessor" method allows you to specify a subroutine that will be
 executed before any of the other conversions take place on the input HTML.
@@ -789,7 +789,7 @@ parameters:
 - reference to content hash
 
 The content hash has been initialized with the "id" and "date" keys when the
-preprocesor is called.  The preprocessor subroutine can make any changes to
+preprocessor is called.  The preprocessor subroutine can make any changes to
 the content hash that it seems fit.  An example of the use of a preprocessor
 subroutine is the L<mhonarc> convenience method that extracts subject, from
 and date information from the HTML which are stored in the content hash.
@@ -797,12 +797,13 @@ and date information from the HTML which are stored in the content hash.
 - HTML to be pre-processed
 
 The second input parameter is the HTML that should be preprocessed.  The result
-of this preprocessing should be returned by the subroutine.
+of this preprocessing should be returned by the subroutine or directly changed
+in the parameter passed.
 
 =head2 removecontainers
 
- $html->removecontainers( qw(embed script) );
- @removecontainer= $html->removecontainers;
+ $converter->removecontainers( qw(embed script) );
+ @removecontainer= $converter->removecontainers;
 
 The "removecontainers" method specifies which HTML-tags, and their content,
 should be removed from the HTML when converting to XML.  The difference with
@@ -813,7 +814,7 @@ The default HTML-tags are: embed script .
 
 =head2 texttype_processor
 
- $html->texttype_processor( 'attribute', key | sub {} );
+ $converter->texttype_processor( 'attribute', key | sub {} );
 
 The "texttype_processor" allows you to specify a subroutine that will process
 the contents of a specific texttype before it becomes serialized in XML.
