@@ -6,7 +6,7 @@ package NexTrieve::RFC822;
 
 use strict;
 @NexTrieve::RFC822::ISA = qw(NexTrieve);
-$NexTrieve::RFC822::VERSION = '0.32';
+$NexTrieve::RFC822::VERSION = '0.33';
 
 # Use other NexTrieve modules that we need always
 
@@ -458,11 +458,11 @@ NexTrieve::RFC822 - convert RFC822 to NexTrieve Document objects
  use NexTrieve;
  $ntv = NexTrieve->new( | {method => value} );
 
- $rfc822 = $ntv->RFC822( | {method => value} );
+ $converter = $ntv->RFC822( | {method => value} );
 
- $document = $rfc822->Document( filename );
+ $document = $converter->Document( filename );
 
- $docseq = $rfc822->Docseq( $ntv->Index( $resource )->Docseq,<*.message> );
+ $docseq = $converter->Docseq( $ntv->Index( $resource )->Docseq,<*.message> );
  $docseq->done;
 
 =head1 DESCRIPTION
@@ -575,11 +575,11 @@ These methods create objects from the NexTrieve::RFC822 object.
 
 =head2 Docseq
 
- $docseq = $rfc822->Docseq( @file );
+ $docseq = $converter->Docseq( @file );
  $docseq->write_file( filename );
 
  $index = $ntv->Index( $resource );
- $rfc822->Docseq( $index->Docseq,@file );
+ $converter->Docseq( $index->Docseq,@file );
 
 The Docseq method allows you to create a NexTrieve document sequence object
 (or NexTrieve::Docseq object) out of one or more messages.  This can either
@@ -604,7 +604,7 @@ NexTrieve::Mbox module.
 
 =head2 Document
 
- $document = $rfc822->Document( file | html | [list] , | '' | 'file' | 'url' | sub {}, {extra} );
+ $document = $converter->Document( file | html | [list] , | '' | 'file' | 'url' | sub {}, {extra} );
 
 The Document method performs the actual conversion from an RFC822-formatted
 message to XML and returns a NexTrieve::Document object that may become part
@@ -669,7 +669,7 @@ in this way, will always be the first value for that key.
 
 =head2 Resource
 
- $resource = $rfc822->Resource( | {method => value} );
+ $resource = $converter->Resource( | {method => value} );
 
 The "Resource" method allows you to create a NexTrieve::Resource object from
 the internal structure of the NexTrieve::RFC822.pm object.  More specifically,
@@ -687,7 +687,7 @@ These methods change aspects of the NexTrieve::RFC822 object.
 
 =head2 attribute_processor
 
- $rfc822->attribute_processor( 'attribute', key | sub {} );
+ $converter->attribute_processor( 'attribute', key | sub {} );
 
 The "attribute_processor" allows you to specify a subroutine that will process
 the contents of a specific attribute before it becomes serialized in XML.
@@ -701,8 +701,8 @@ L<PROCESSOR ROUTINES> for more information.
 
 =head2 binarycheck
 
- $html->binarycheck( true | false );
- $binarycheck = $html->binarycheck;
+ $converter->binarycheck( true | false );
+ $binarycheck = $converter->binarycheck;
 
 The "binarycheck" method sets a flag in the object to indicate whether a
 check for binary content should be performed.  If the flag is set and binary
@@ -715,24 +715,24 @@ listed are really messages, it is probably a good idea to set this flag.
 
 =head2 DefaultInputEncoding
 
- $encoding = $rfc822->DefaultInputEncoding;
- $rfc822->DefaultInputEncoding( encoding );
+ $encoding = $converter->DefaultInputEncoding;
+ $converter->DefaultInputEncoding( encoding );
 
 See the NexTrieve.pm module for more information about the
 "DefaultInputEncoding" method.
 
 =head2 displaycontainers
 
- $rfc822->displaycontainers( qw(a b em font i strike strong tt u) );
- @displaycontainer= $rfc822->displaycontainers;
+ $converter->displaycontainers( qw(a b em font i strike strong tt u) );
+ @displaycontainer= $converter->displaycontainers;
 
 The "displaycontainers" method specifies which HTML-tags should be considered
 HTML-tags that have to do with the display of HTML, rather than with the
 structure of HTML.  During the conversion from any part of the message
 considered to be HTML to XML, all HTML-tags that are considered to be display
 containers, are completelyb removed from the HTML.  This causes the HTML
-"<B>T</B>ext" to be converted to the single word "Text" rather than to two
-words "T ext".
+"<B>1</B>234" to be converted to the single word "1234" rather than to two
+words "1 234".
 
 Please note that all HTML-tags that are not known to be display containers,
 or removable containers (see L<removecontainers>) are completely removed from
@@ -742,7 +742,7 @@ The default display containers are: a b em font i strike strong tt u .
 
 =head2 extra_attribute
 
- $rfc822->extra_attribute( [\$var | sub {}, attribute spec] | 'reset' );
+ $converter->extra_attribute( [\$var | sub {}, attribute spec] | 'reset' );
 
 The "extra_attribute" method specifies one or more attributes that should be
 added to the serialized XML, created from sources outside of the original
@@ -774,7 +774,7 @@ of the object.
 
 =head2 extra_texttype
 
- $rfc822->extra_texttype( [\$var | sub {}, texttype spec] | 'reset' );
+ $converter->extra_texttype( [\$var | sub {}, texttype spec] | 'reset' );
 
 The "extra_texttype" method specifies one or more texttypes that should be
 added to the serialized XML, created from sources outside of the original
@@ -806,7 +806,7 @@ of the object.
 
 =head2 field2attribute
 
- $html->field2attribute( 'subject','date',['id',attribute spec] );
+ $converter->field2attribute( 'subject','date',['id',attribute spec] );
 
 The "field2attribute" specifies how a key in the content hash should be mapped
 to an attribute in the serialized XML.
@@ -829,7 +829,7 @@ cause a complete resource-specification if the L<Resource> method is called.
 
 =head2 field2texttype
 
- $html->field2texttype( 'from',[qw(subject title 200)],'to' );
+ $converter->field2texttype( 'from',[qw(subject title 200)],'to' );
 
 The "field2texttype" specifies how a key in the content hash should be mapped
 to a texttype in the serialized XML.
@@ -853,7 +853,7 @@ method is called.
 
 =head2 mailsimple
 
- $html->mailsimple;
+ $converter->mailsimple;
 
 The "mailsimple" method is a convenience method for quickly setting up
 L<field2attribute> and L<field2texttype> mappings.  It is intended to handle
@@ -868,8 +868,8 @@ one-liners.
 
 =head2 removecontainers
 
- $rfc822->removecontainers( qw(embed script) );
- @removecontainer= $rfc822->removecontainers;
+ $converter->removecontainers( qw(embed script) );
+ @removecontainer= $converter->removecontainers;
 
 The "removecontainers" method specifies which HTML-tags, and their content,
 should be removed from the HTML when converting any HTML found in a message
@@ -880,7 +880,7 @@ The default HTML-tags are: embed script .
 
 =head2 texttype_processor
 
- $rfc822->texttype_processor( 'attribute', key | sub {} );
+ $converter->texttype_processor( 'attribute', key | sub {} );
 
 The "texttype_processor" allows you to specify a subroutine that will process
 the contents of a specific texttype before it becomes serialized in XML.
